@@ -22,7 +22,7 @@
 #' @author Qin Wenfeng
 #' @export
 tagging<- function(code, jiebar) {
-  stopifnot("tagger" %in% class(jiebar))
+  stopifnot("jieba" %in% class(jiebar))
   if(jiebar$PrivateVarible$timestamp != TIMESTAMP){
     stop("Please create a new worker after jiebaR is reloaded.")
   }
@@ -62,14 +62,6 @@ tagging<- function(code, jiebar) {
   }
 }
 
-#' @rdname tagging
-#' @export
-tag <- function(code, jiebar){
-  warning("The tag() function is deprecated for shiny package. Please use tagging() instead.")
-  tagging(code, jiebar)
-}
-  
-
 tagl <- function(code, jiebar, symbol, lines, output, encoding, write_file,FILESMODE) {
   
   nlines <- lines
@@ -182,11 +174,12 @@ tagw <- function(code, jiebar,  symbol, FILESMODE) {
     if(length(code) > 1){
       code <- paste(code, collapse = " ")
     }
-    if(FILESMODE==T ){
-      result <- tag_file(code, jiebar$worker)
+    if(FILESMODE==T && symbol == T){
+        result <- jiebaclass_tag_file(code,jiebar$worker)
     } else{
-      result <- tag_tag(code, jiebar$worker)
+        result <- jiebaclass_tag_tag(code,jiebar$worker)
     }
+    
     if (symbol == F && FILESMODE  ==F) {
       result = result[ result != " "]
     }
@@ -194,30 +187,46 @@ tagw <- function(code, jiebar,  symbol, FILESMODE) {
     if (.Platform$OS.type == "windows") {
       Encoding(result)<-"UTF-8"
     }
-    if (symbol == F) {
+
+    if(FILESMODE==T && symbol == F){
+      result = grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", result, perl = TRUE,value = TRUE,invert = T)
+      result = paste(result,names(result),collapse = " ")
+    }
+
+    if (symbol == F && FILESMODE  == F) {
       result <- grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", result, perl = TRUE,value = TRUE,invert = T)
     }
+
   } else{
     
     length_of_input = length(code)
     result = vector("list", length_of_input)
     
     for(num in 1:length_of_input){
-      if(FILESMODE==T ){
-        tmp_result <- tag_file(code[num], jiebar$worker)
+      if(FILESMODE==T && symbol == T){
+          tmp_result <- jiebaclass_tag_file(code[num], jiebar$worker)
+        
       } else{
-        tmp_result <- tag_tag(code[num], jiebar$worker)
+          tmp_result <- jiebaclass_tag_tag(code[num],jiebar$worker)
       }
-      if (symbol == F && FILESMODE  ==F) {
+      
+      if (symbol == F && FILESMODE  == F) {
         tmp_result = tmp_result[ tmp_result != " "]
       }
       
       if (.Platform$OS.type == "windows") {
         Encoding(tmp_result)<-"UTF-8"
       }
-      if (symbol == F) {
+
+      if(FILESMODE==T && symbol == F){
+        tmp_result = grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", tmp_result, perl = TRUE,value = TRUE,invert = T)
+        tmp_result = paste(tmp_result,names(tmp_result),collapse = " ")
+      }
+
+      if (FILESMODE == F && symbol == F) {
         tmp_result <- grep("(*UCP)^[^\u2e80-\u3000\u3021-\ufe4fa-zA-Z0-9]*$", tmp_result, perl = TRUE,value = TRUE,invert = T)
       }
+      
       result[[num]] = tmp_result
     }
   }
